#
# spec file for package python-blinker
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-blinker
Version:        1.6.2
Release:        150400.12.3.8
Summary:        Object-to-object and broadcast signaling in Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/pallets-eco/blinker/
Source:         https://files.pythonhosted.org/packages/source/b/blinker/blinker-%{version}.tar.gz
BuildRequires:  %{python_module Pallets-Sphinx-Themes}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module sphinx-issues}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Blinker provides a dispatching system that allows any number of
interested parties to subscribe to events, or "signals".

Signal receivers can subscribe to specific senders or receive signals
sent by any sender.

%if 0%{?suse_version} > 1500
%package -n python-blinker-doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
Provides:       %{python_module blinker-doc = %{version}}

%description -n python-blinker-doc
Blinker provides a dispatching system that allows any number of
interested parties to subscribe to events, or "signals".

Signal receivers can subscribe to specific senders or receive signals
sent by any sender.

This sub-package contains the HTML documentation.
%endif

%prep
%autosetup -p1 -n blinker-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

%{python_expand pushd docs
export PYTHONPATH=%{buildroot}%{$python_sitelib}
# Do not call "make html" directly because it'll use python3 by
# default and that could produce .pyc files from different python
# versions in the package bsc#1213698
$python -m sphinx -M html . _build
popd

%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pytest

%files %{python_files}
%license LICENSE.rst
%doc CHANGES.rst README.rst
%{python_sitelib}/blinker-%{version}*-info
%{python_sitelib}/blinker

%if 0%{?suse_version} > 1500
%files -n python-blinker-doc
%endif
%doc docs/_build/html

%changelog
* Mon Jul 31 2023 daniel.garcia@suse.com
- Remove no-stdpy-pyc.patch
- Call directly to the sphinx module with the specific python
  interpreter to avoid the usage of default python, bsc#1213698.
* Wed Jul 26 2023 mcepl@suse.com
- Add no-stdpy-pyc.patch which makes Sphinx not to generate
  * .pyc files for the Python interpreter it uses for generating
  documentation.
* Tue May  9 2023 daniel.garcia@suse.com
- Update to 1.6.2:
  * Type annotations are not evaluated at runtime. typing-extensions
    is not a runtime dependency. :pr:`94`
- 1.6.1:
  * Ensure that py.typed is present in the distributions (to enable
    other projects to use blinker's typing).
  * Require typing-extensions > 4.2 to ensure it includes ParamSpec.
    :issue:`90`
- 1.6:
  * Add a muted context manager to temporarily turn off a signal.
    :pr:`84`
  * Allow int senders (alongside existing string senders). :pr:`83`
  * Add a send_async method to the Signal to allow signals to send to
    coroutine receivers. :pr:`76`
  * Update and modernise the project structure to match that used by
    the pallets projects. :pr:`77`
  * Add an intial set of type hints for the project.
* Sun Apr 23 2023 mcepl@suse.com
- move documentation into the main package for SLE15
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Wed Sep 14 2022 mcepl@suse.com
- Fix documentation generation.
* Mon Sep 12 2022 arun@gmx.de
- specfile:
  * update copyright year
  * remove patch python-blinker-remove-nose.patch; included upstream
  * docs and license changed to .rst
  * build docs using Sphinx
- update to version 1.5:
  * Support Python >= 3.7 and PyPy. Python 2, Python < 3.7, and Jython
    may continue to work, but the next release will make incompatible
    changes.
* Wed Jul  8 2020 pgajdos@suse.com
- use pytest instead of deprecated nose
- added patches
  https://github.com/jek/blinker/pull/60
  + python-blinker-remove-nose.patch
* Thu Dec  6 2018 tchvatal@suse.com
- Fix fdupes call
* Wed Dec  5 2018 jengelh@inai.de
- Trim bias from description.
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Sun May  7 2017 benoit.monin@gmx.fr
- convert the package to singlespec
- call fdupes to fix duplicated files
- remove unneeded buildrequires: unzip
- remove unneded doc file that trigger rpmlint
- put the documentation in a separate sub-package
* Thu Sep 15 2016 rjschwei@suse.com
- Include in SLES 12 (FATE#321371, bsc#998103)
* Fri Mar 11 2016 freitag@opensuse.org
- use setup.py option to record file list for rpm package
* Sun Jan  3 2016 freitag@opensuse.org
- Fixed doc section in file list
* Sun Jan  3 2016 freitag@opensuse.org
- update to version 1.4:
  * Verified Python 3.4 support (no changes needed)
  * Additional bookkeeping cleanup for non-ANY connections at disconnect
    time.
  * Added Signal._cleanup_bookeeping() to prune stale bookkeeping on
    demand
* Sun Feb 22 2015 benoit.monin@gmx.fr
- update to version 1.3:
  * The global signal stash behind blinker.signal() is now backed
    by a regular name-to-Signal dictionary
  * blinker.Namespace is now built on a regular dict
  * Signal.connect('text-sender') uses an alterate hashing strategy
    to avoid sharp edges in text identity.
* Wed Aug 15 2012 highwaystar.ru@gmail.com
- python3 package added
- spec improved (files section)
* Fri Jun 22 2012 saschpe@suse.de
- Update to version 1.2:
  + Added Signal.receiver_connected and
    Signal.receiver_disconnected per-Signal signals.
  + Deprecated the global 'receiver_connected' signal.
  + Verified Python 3.2 support (no changes needed!)
* Fri Sep 23 2011 saschpe@suse.de
- Initial version
